duplicate_text.pdf

## Metadata

Title | duplicate_text.pdf
Path | C:\Users\jenni\OneDrive\Documents\Code\burdoc\burdoc\tests\integration\data\inputs\duplicate_text.pdf
Pages | 0
PDF Metadata: format | PDF 1.7
PDF Metadata: title |
PDF Metadata: author | Joe Ennis
PDF Metadata: subject |
PDF Metadata: keywords |
PDF Metadata: creator | Microsoft® Word for Microsoft 365
PDF Metadata: producer | Microsoft® Word for Microsoft 365
PDF Metadata: creationDate | D:20230403054739+01'00'
PDF Metadata: modDate | D:20230403054739+01'00'
PDF Metadata: trapped |
PDF Metadata: encryption |

## Contents

1. Page 0

#### Page 0

No images

Path: | content.0.[0,0].bbox
Type: | addition

Key | Old | New
x1 |  | 191.0658721923828
y1 |  | 107.29998016357422
y0 |  | 96.25997924804688
x0 |  | 70.34400177001953

Path: | content.0.[1,1].bbox
Type: | addition

Key | Old | New
x1 |  | 236.0658721923828
y1 |  | 166.8199920654297
y0 |  | 141.25997924804688
x0 |  | 70.34400177001953

Path: | content.0.[2,2].bbox
Type: | addition

Key | Old | New
x1 |  | 199.4658660888672
y1 |  | 207.85997009277344
y0 |  | 196.81997680664062
x0 |  | 74.18399810791016

Path: | content.0.[3,3].bbox
Type: | addition

Key | Old | New
x1 |  | 180.47586059570312
y1 |  | 244.12998962402344
y0 |  | 233.08999633789062
x0 |  | 73.8239974975586

Path: | content.0.[4,4].bbox
Type: | addition

Key | Old | New
x1 |  | 181.91586303710938
y1 |  | 274.489990234375
y0 |  | 263.4499816894531
x0 |  | 73.8239974975586

Path: | content.0.[5,5].bbox
Type: | addition

Key | Old | New
x1 |  | 202.4658660888672
y1 |  | 302.69000244140625
y0 |  | 291.6499938964844
x0 |  | 75.38400268554688

Path: | content.0.[6,6].bbox
Type: | addition

Key | Old | New
x1 |  | 193.94586181640625
y1 |  | 355.25
y0 |  | 335.80999755859375
x0 |  | 73.8239974975586

This is some duplicate text

And this is some more duplicate text followed by another duplicate line.

This is some shadowed text

First word is duplicated

First letter is duplicated

A middle word is duplicated

This Line is not a duplicate This Line is not a duplicate

This is some duplicate text

And this is some more duplicate text followed by another duplicate line.

This is some shadowed text

First word is duplicated

First letter is duplicated

A middle word is duplicated

This Line is not a duplicate This Line is not a duplicate

Parent File Contents